% Runs synthetic experiments
function run_synth_exps_iterative_updates_of_btc_result_sparse
    resdir = '../experiments/synth/';
    iters = 5;

    datadir = '../experiments/synth/data_density5percent/';
    algname = 'iterative_updates_of_btc_result_density5percent';
    btc_result_folder = 'bitwise_btc_density5percent';

    n = 700;
    m = 500;
    l = 50;

    K = 3:2:15;
    D = 0.05:0.05:0.3;
    addNoise = 0.05:0.05:0.5;
    desNoise = 0.05:0.05:0.5;

    defK = 7;
    defD = 0.05;
    defAddNoise = 0.1;
    defDesNoise = 0.1;

 
     %% K
    d = defD;
    dnoise = defDesNoise;
    anoise = defAddNoise;

    S = nan(iters, length(K));
    SO = nan(iters, length(K));
    Time = nan(iters, length(K));
    j = 0;

    for k=K
        fprintf(2, 'k = %i ', k);
        j = j + 1; 
        for i=1:iters
            fprintf(2, '.');
            [S(i, j), SO(i, j), Time(i, j)] = run_experiment (datadir, btc_result_folder, ...
                'k', resdir, algname, n, m, l, k, d, dnoise, anoise, i);
        end
        fprintf(2, '\n');
        save(sprintf('%sk_%s.mat', resdir, algname), 'S', 'SO', 'Time');
    end


    %% D
    k = defK;
    dnoise = defDesNoise;
    anoise = defAddNoise;

    S = nan(iters, length(D));
    SO = nan(iters, length(D));
    Time = nan(iters, length(D));
    j = 0;

    for d=D
        fprintf(2, 'd = %.2f', d);
        j = j + 1;
        for i=1:iters
            fprintf(2, '.');
            [S(i, j), SO(i, j), Time(i, j)] = run_experiment (datadir, btc_result_folder, ...
                'd', resdir, algname, n, m, l, k, d, dnoise, anoise, i);
        end
        fprintf(2, '\n');   
        save(sprintf('%sdensity_%s.mat', resdir, algname), 'S', 'SO', 'Time');
    end


    %% destructive Noise
    k = defK;
    d = defD;
    anoise = defAddNoise;

    S = nan(iters, length(desNoise));
    SO = nan(iters, length(desNoise));
    Time = nan(iters, length(desNoise));
    j = 0;

    for dnoise=desNoise
        fprintf(2, 'dnoise = %.2f', dnoise);
        j = j + 1;
        for i=1:iters
            fprintf(2, '.');
            [S(i, j), SO(i, j), Time(i, j)] = run_experiment (datadir, btc_result_folder, ...
                'desNoise', resdir, algname, n, m, l, k, d, dnoise, anoise, i);
        end
        fprintf(2, '\n');
        save(sprintf('%sdesNoise_%s.mat', resdir, algname), 'S', 'SO', 'Time');
    end
    
    %% additive Noise
    k = defK;
    d = defD;
    dnoise = defDesNoise;
    
    S = nan(iters, length(addNoise));
    SO = nan(iters, length(addNoise));
    Time = nan(iters, length(addNoise));
    j = 0;

    for anoise=addNoise
        fprintf(2, 'anoise = %.2f', anoise);
        j = j + 1;
        for i=1:iters
            fprintf(2, '.');
            [S(i, j), SO(i, j), Time(i, j)] = run_experiment (datadir, btc_result_folder, ...
                'addNoise', resdir, algname, n, m, l, k, d, dnoise, anoise, i);
        end
        fprintf(2, '\n');
        save(sprintf('%saddNoise_%s.mat', resdir, algname), 'S', 'SO', 'Time');
    end
end
        
function [simi, sim_orig, time] = run_experiment (datadir, btc_result_folder, prefix, resdir, algname, n, m, l, k, d, dnoise, anoise, i)
        load(sprintf('%s%s_n%i_m%i_l%i_k%i_d%.2f_desNoise%.2f_addNoise%.2f_iter%i.mat', ...
            datadir, prefix, n, m, l, k, d, dnoise, anoise, i));
        BTCres = load(sprintf('%s/%s/%s_n%i_m%i_l%i_k%i_d%.2f_desNoise%.2f_addNoise%.2f_iter%i.mat', ...
            resdir, btc_result_folder, prefix, n, m, l, k, d, dnoise, anoise, i));
        tic
        [mA1,mA2,mA3] = find(BTCres.mA); 
        [mB1,mB2,mB3] = find(BTCres.mB); 
        [mC1,mC2,mC3] = find(BTCres.mC); 
        [centroids, assignment, simi] = iterative_updates_of_btc_result(T.subs, ...
            [mA1,mA2,mA3], [mB1,mB2,mB3], [mC1,mC2,mC3], T.size, k, BTCres.sim);
        time = toc;
        
        %OT = bclust2sptens(A, B, C);
        %AT = bclust2sptens(mA, mB, mC);
        sim_orig = 0; %m*n*l-nnz(xor(OT, AT));
        
        save(sprintf('%s/%s/%s_n%i_m%i_l%i_k%i_d%.2f_desNoise%.2f_addNoise%.2f_iter%i.mat', ...
            resdir, algname, prefix, n, m, l, k, d, dnoise, anoise, i), ...
            'centroids', 'assignment', 'time', 'simi', 'sim_orig');
        clear T centroids assignment OT AT;
end
